@@ -1,7 +1,7 @@
 use alloc::borrow::Cow;
 
 #[derive(Clone, Debug, Eq, PartialEq)]
-pub enum ExitError {
+pub enum Return {
     Exit,
     OutOfGas,
     /// Other normal errors.
