@@ -9,8 +9,6 @@ mod error;
 mod hash;
 mod identity;
 mod modexp;
-
-#[cfg(feature = "secp256k1")]
 mod secp256k1;
 
 pub use error::Return;
@@ -38,7 +36,7 @@ pub struct PrecompileOutput {
     pub logs: Vec<Log>,
 }
 
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct Log {
     pub address: Address,
     pub topics: Vec<H256>,
@@ -55,16 +53,6 @@ impl PrecompileOutput {
     }
 }
 
-impl Default for PrecompileOutput {
-    fn default() -> Self {
-        PrecompileOutput {
-            cost: 0,
-            output: Vec::new(),
-            logs: Vec::new(),
-        }
-    }
-}
-
 /// A precompile operation result.
 pub type PrecompileResult = Result<PrecompileOutput, Return>;
 
@@ -107,7 +95,6 @@ impl Precompiles {
         if SpecId::HOMESTEAD.enabled(SPEC_ID) {
             fun.push(hash::SHA256);
             fun.push(hash::RIPED160);
-            #[cfg(feature = "secp256k1")]
             fun.push(secp256k1::ECRECOVER);
             fun.push(identity::FUN);
         }
